@@ -33,8 +33,11 @@
 #include <Solid/Device>
 #include <Solid/DeviceNotifier>
 
-#include <KAuthExecuteJob>
-#include <KAuthAction>
+
+#include <kauth_version.h>
+#include <KAuth/Action>
+#include <KAuth/ExecuteJob>
+
 #include <KIdleTime>
 #include <KLocalizedString>
 #include <KNotification>
@@ -49,7 +52,7 @@
 #include <QDebug>
 
 #include <algorithm>
-#include <TabletModeWatcher>
+#include <Kirigami/TabletModeWatcher>
 
 #ifdef Q_OS_LINUX
 #include <sys/timerfd.h>
@@ -543,7 +546,7 @@ void Core::emitRichNotification(const QString &evid, const QString &title, const
                          nullptr, KNotification::CloseOnTimeout, QStringLiteral("powerdevil"));
 }
 
-bool Core::emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi)
+bool Core::emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi, Core::ChargeNotificationFlags flags)
 {
     using namespace Solid;
     Device device(udi);
@@ -569,23 +572,19 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
                 name = i18nc("%1 is vendor name, %2 is product name", "%1 %2", device.vendor(), device.product());
             }
 
-            QString title;
-            QString msg;
-            QString icon;
+            QString title = i18nc("The battery in an external device", "Device Battery Low (%1% Remaining)", currentPercent);
+            QString msg = i18nc("Placeholder is device name",
+                                      "The battery in \"%1\" is running low, and the device may turn off at any time. "
+                                      "Please recharge or replace the battery.", name);
+            QString icon = QStringLiteral("battery-caution");
 
             switch(b->type()) {
             case Battery::MouseBattery:
                 title = i18n("Mouse Battery Low (%1% Remaining)", currentPercent);
-                msg = i18nc("Placeholder is device name",
-                            "The battery in (\"%1\") is running low, and the device may turn off at any time. "
-                            "Please recharge or replace the battery.", name);
                 icon = QStringLiteral("input-mouse");
                 break;
             case Battery::KeyboardBattery:
                 title = i18n("Keyboard Battery Low (%1% Remaining)", currentPercent);
-                msg = i18nc("Placeholder is device name",
-                            "The battery in (\"%1\") is running low, and the device may turn off at any time. "
-                            "Please recharge or replace the battery.", name);
                 icon = QStringLiteral("input-keyboard");
                 break;
             case Battery::BluetoothBattery:
@@ -596,11 +595,6 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
                 icon = QStringLiteral("preferences-system-bluetooth");
                 break;
             default:
-                title = i18nc("The battery in an external device", "Device Battery Low (%1% Remaining)", currentPercent);
-                msg = i18nc("Placeholder is device name",
-                            "The battery in (\"%1\") is running low, and the device may turn off at any time. "
-                            "Please recharge or replace the battery.", name);
-                icon = QStringLiteral("battery-caution");
                 break;
             }
 
@@ -612,7 +606,11 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
         return false;
     }
 
-    if (m_backend->acAdapterState() == BackendInterface::Plugged) {
+    // Make sure a notificaton that's kept open updates its percentage live.
+    updateBatteryNotifications(currentPercent);
+
+    if (m_backend->acAdapterState() == BackendInterface::Plugged
+            && !flags.testFlag(ChargeNotificationFlag::NotifyWhenAcPluggedIn)) {
         return false;
     }
 
@@ -636,8 +634,12 @@ void Core::handleLowBattery(int percent)
 
     m_lowBatteryNotification = new KNotification(QStringLiteral("lowbattery"), KNotification::Persistent, nullptr);
     m_lowBatteryNotification->setComponentName(QStringLiteral("powerdevil"));
-    m_lowBatteryNotification->setTitle(i18n("Battery Low (%1% Remaining)", percent));
-    m_lowBatteryNotification->setText(i18n("Battery running low - to continue using your computer, plug it in or shut it down and change the battery."));
+    updateBatteryNotifications(percent); // sets title
+    if (m_backend->acAdapterState() == BackendInterface::Plugged) {
+        m_lowBatteryNotification->setText(i18n("Battery running low - to continue using your computer, make sure that the power adapter is plugged in and that it provides enough power."));
+    } else {
+        m_lowBatteryNotification->setText(i18n("Battery running low - to continue using your computer, plug it in or shut it down and change the battery."));
+    }
     m_lowBatteryNotification->setUrgency(KNotification::CriticalUrgency);
     m_lowBatteryNotification->sendEvent();
 }
@@ -651,7 +653,7 @@ void Core::handleCriticalBattery(int percent)
     // no parent, but it won't leak, since it will be closed both in case of timeout or direct action
     m_criticalBatteryNotification = new KNotification(QStringLiteral("criticalbattery"), KNotification::Persistent, nullptr);
     m_criticalBatteryNotification->setComponentName(QStringLiteral("powerdevil"));
-    m_criticalBatteryNotification->setTitle(i18n("Battery Critical (%1% Remaining)", percent));
+    updateBatteryNotifications(percent); // sets title
 
     const QStringList actions = {i18nc("Cancel timeout that will automatically put system to sleep because of low battery", "Cancel")};
 
@@ -685,6 +687,17 @@ void Core::handleCriticalBattery(int percent)
     m_criticalBatteryNotification->sendEvent();
 }
 
+void Core::updateBatteryNotifications(int percent)
+{
+    if (m_lowBatteryNotification) {
+        m_lowBatteryNotification->setTitle(i18n("Battery Low (%1% Remaining)", percent));
+    }
+
+    if (m_criticalBatteryNotification) {
+        m_criticalBatteryNotification->setTitle(i18n("Battery Critical (%1% Remaining)", percent));
+    }
+}
+
 void Core::onAcAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState state)
 {
     qCDebug(POWERDEVIL);
@@ -735,7 +748,8 @@ void Core::onBatteryChargePercentChanged(int percent, const QString &udi)
     m_batteriesPercent[udi] = percent;
 
     if (currentPercent < previousPercent) {
-        if (emitBatteryChargePercentNotification(currentPercent, previousPercent, udi)) {
+        // When battery drains while still plugged in, warn nevertheless.
+        if (emitBatteryChargePercentNotification(currentPercent, previousPercent, udi, ChargeNotificationFlag::NotifyWhenAcPluggedIn)) {
             // Only refresh status if a notification has actually been emitted
             loadProfile();
         }
