@@ -48,6 +48,22 @@ class OrgFreedesktopScreenSaverInterface;
 
 using InhibitionInfo = QPair<QString, QString>;
 
+struct LogindInhibition
+{
+    QString what;
+    QString who;
+    QString why;
+    QString mode;
+    uint pid;
+    uint uid;
+
+    bool operator==(const LogindInhibition &other) const
+    {
+        return what == other.what && who == other.who && why == other.why && mode == other.mode
+                && pid == other.pid && uid == other.uid;
+    }
+};
+
 namespace PowerDevil
 {
 
@@ -79,6 +95,8 @@ public:
 
     RequiredPolicies unavailablePolicies();
 
+    bool screenLockerActive() const;
+
     void setupSystemdInhibition();
 
 public Q_SLOTS:
@@ -96,6 +114,7 @@ Q_SIGNALS:
 
     void unavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies newpolicies);
     void sessionActiveChanged(bool active);
+    void screenLockerActiveChanged(bool active);
 
 private Q_SLOTS:
     void onServiceUnregistered(const QString & serviceName);
@@ -104,6 +123,8 @@ private Q_SLOTS:
     void onActiveSessionChanged(const QString & ifaceName, const QVariantMap & changedProps, const QStringList & invalidatedProps);
     void onActiveSessionChanged(const QString &activeSession);
 
+    void onManagerPropertyChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps);
+
 private:
     explicit PolicyAgent(QObject* parent = nullptr);
 
@@ -113,6 +134,8 @@ private:
 
     void addInhibitionTypeHelper(uint cookie, RequiredPolicies types);
 
+    void checkLogindInhibitions();
+
     // Screen locker integration
     void onScreenLockerOwnerChanged(const QString &serviceName, const QString &oldOwner, const QString &newOwner);
     QDBusServiceWatcher *m_screenLockerWatcher;
@@ -146,6 +169,8 @@ private:
     QHash< uint, QString > m_cookieToBusService;
     QHash< RequiredPolicy, QList< uint > > m_typesToCookie;
 
+    QHash<uint, LogindInhibition> m_logindInhibitions;
+
     QVector<int> m_pendingInhibitions;
 
     uint m_lastCookie;
